this package "fileretor" contains a function which is -
run():-
 Defenition :-this function can take a variable in which a code is input and get the output and store it in a variable.
 Paranthesis :- at first the code(or the variable)and after comma the extention in string.
 IMPORTANT NOTE:-The  code in a lanaguage can be only run when it is present/installed in the computer 
 how to install the code:-
 " pip install fileretor" in your terminal then write -
 "import fileretor" or "from fileretor import run"
 how to use(example):-
  input:-
  a ="print('fileretor')"
  l = run(a,"py")
  print (l)
 output:-
  fileretor  
      ! This function only work in windows !